@@ -331,24 +331,23 @@ def html_id(object: typing.Any, prefix: str = "id") -> str:
 class ContextFormatter(string.Formatter):
     context: dict
 
-    def __init__(self, context: dict, autoescape: bool):
+    def __init__(self, context: dict):
         super().__init__()
         self.context = context
-        self.autoescape = autoescape
 
     def format(self, format_string, *args, **kwargs):
         return mark_safe(super().format(format_string, *args, **kwargs))
 
     def parse(self, format_string):
+        # need to preserve type of the original format_string in order to
+        # be able to return correctly typed splitted literals
+        format_string_type = type(format_string)
         for literal_text, field_name, format_spec, conversion in super().parse(
             str(format_string)
         ):
-            if self.autoescape:
-                yield conditional_escape(
-                    literal_text
-                ), field_name, format_spec, conversion
-            else:
-                yield literal_text, field_name, format_spec, conversion
+            yield conditional_escape(
+                format_string_type(literal_text)
+            ), field_name, format_spec, conversion
 
     def get_value(self, key, args, kwds):
         def extract(value):
@@ -361,28 +360,25 @@ class ContextFormatter(string.Formatter):
             [extract(arg) for arg in args],
             {k: extract(v) for k, v in kwds.items()},
         )
-        return conditional_escape(ret) if self.autoescape else ret
+        return conditional_escape(ret)
 
 
 class FormatString(BaseElement):
-    def __init__(self, *args, autoescape, **kwargs):
+    def __init__(self, *args, **kwargs):
         super().__init__()
         self.args = args
         self.kwargs = kwargs
-        self.autoescape = autoescape
 
     def render(self, context):
         yield from self._try_render(
-            ContextFormatter(context, autoescape=self.autoescape).format(
-                *self.args, **self.kwargs
-            ),
+            ContextFormatter(context).format(*self.args, **self.kwargs),
             context,
             stringify=True,
         )
 
 
-def format(*args, autoescape=True, **kwargs):
-    return FormatString(*args, autoescape=autoescape, **kwargs)
+def format(*args, **kwargs):
+    return FormatString(*args, **kwargs)
 
 
 def _handle_exception(exception, context):
